@@ -76,6 +76,10 @@ class Manager:
     # Working with AIO-Databases
     # --------------------------
 
+    @property
+    def current_conn(self):
+        return self.aio_database.current_conn
+
     async def connect(self):
         """Connect to the database (initialize the database's pool)"""
         await self.aio_database.connect()
@@ -160,7 +164,7 @@ class Manager:
 
     def run(self, query: Query, *, iterate: bool = False) -> t.Any:
         """Run the given Peewee ORM Query."""
-        if isinstance(query, (Select, ModelRaw)):
+        if isinstance(query, (Select, ModelRaw)) or query._returning:
             return RunWrapper(self, query)
 
         return self.execute(query)
